==> jc-1.4.0.tar.gz: jas/LocalVarTableAttr.h <==
// public class jas.LocalVarTableAttr

// class file dependencies
// @dep_class a8d3d3e498ab7bbc jas_LocalVarTableAttr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_LocalVarTableAttr_H_
#define _JC_jas_LocalVarTableAttr_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_LocalVarEntry$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_jas_LocalVarTableAttr$sub_refs	_jc_jas_LocalVarTableAttr$sub_refs;
typedef struct _jc_jas_LocalVarTableAttr$sub_nonrefs	_jc_jas_LocalVarTableAttr$sub_nonrefs;
typedef struct _jc_jas_LocalVarTableAttr$refs	_jc_jas_LocalVarTableAttr$refs;
typedef struct _jc_jas_LocalVarTableAttr$nonrefs	_jc_jas_LocalVarTableAttr$nonrefs;
typedef struct _jc_jas_LocalVarTableAttr$object	_jc_jas_LocalVarTableAttr$object;

typedef struct _jc_jas_LocalVarTableAttr$fields_struct	_jc_jas_LocalVarTableAttr$fields_struct;
typedef const struct _jc_jas_LocalVarTableAttr$vmethods	_jc_jas_LocalVarTableAttr$vmethods;
typedef const struct _jc_jas_LocalVarTableAttr$vtable	_jc_jas_LocalVarTableAttr$vtable;
typedef const struct _jc_jas_LocalVarTableAttr$vtype	_jc_jas_LocalVarTableAttr$vtype;

// Class fields structure
struct _jc_jas_LocalVarTableAttr$fields_struct {
	struct _jc_jas_CP$object	*attr;
};
extern _jc_jas_LocalVarTableAttr$fields_struct _jc_jas_LocalVarTableAttr$class_fields;

// Constructors
extern void _jc_jas_LocalVarTableAttr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *);

// Virtual methods
extern void _jc_jas_LocalVarTableAttr$method$addEntry$c7f050ddb6c94fc1(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *, struct _jc_jas_LocalVarEntry$object *);
extern void _jc_jas_LocalVarTableAttr$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *, struct _jc_jas_ClassEnv$object *);
extern jint _jc_jas_LocalVarTableAttr$method$size$345df5220fc60ade(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *);
extern void _jc_jas_LocalVarTableAttr$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_LocalVarTableAttr$method_info$addEntry$c7f050ddb6c94fc1;
extern _jc_method _jc_jas_LocalVarTableAttr$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_LocalVarTableAttr$method_info$size$345df5220fc60ade;
extern _jc_method _jc_jas_LocalVarTableAttr$method_info$write$d61e8c36d8c1cacd;

// Static methods
extern void _jc_jas_LocalVarTableAttr$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_jas_LocalVarTableAttr$vmethods {
	void	(*addEntry$c7f050ddb6c94fc1)(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *, struct _jc_jas_LocalVarEntry$object *);
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *, struct _jc_jas_ClassEnv$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *);
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_LocalVarTableAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_LocalVarTableAttr$vmethods	jas_LocalVarTableAttr;
};

// Vtype
struct _jc_jas_LocalVarTableAttr$vtype {
	_jc_type			type;
	_jc_jas_LocalVarTableAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LocalVarTableAttr$sub_refs {
	struct _jc_java_util_Vector$object	*vars;
};

// Reference instance fields (object)
struct _jc_jas_LocalVarTableAttr$refs {
    _jc_jas_LocalVarTableAttr$sub_refs	jas_LocalVarTableAttr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LocalVarTableAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_LocalVarTableAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_LocalVarTableAttr$sub_nonrefs	jas_LocalVarTableAttr;
};

// Object instance structure
struct _jc_jas_LocalVarTableAttr$object {
	_jc_jas_LocalVarTableAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LocalVarTableAttr$vtype	*vtype;
	_jc_jas_LocalVarTableAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LocalVarTableAttr$vtype _jc_jas_LocalVarTableAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LocalVarTableAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LocalVarTableAttr$class_object;

#endif	/* _JC_jas_LocalVarTableAttr_H_ */

==> jc-1.4.6.tar.gz: jas/LocalVarTableAttr.h <==
// public class jas.LocalVarTableAttr

// class file dependencies
// @dep_class a8d3d3e498ab7bbc jas_LocalVarTableAttr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_LocalVarTableAttr_H_
#define _JC_jas_LocalVarTableAttr_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_LocalVarEntry$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_jas_LocalVarTableAttr$sub_refs	_jc_jas_LocalVarTableAttr$sub_refs;
typedef struct _jc_jas_LocalVarTableAttr$sub_nonrefs	_jc_jas_LocalVarTableAttr$sub_nonrefs;
typedef struct _jc_jas_LocalVarTableAttr$refs	_jc_jas_LocalVarTableAttr$refs;
typedef struct _jc_jas_LocalVarTableAttr$nonrefs	_jc_jas_LocalVarTableAttr$nonrefs;
typedef struct _jc_jas_LocalVarTableAttr$object	_jc_jas_LocalVarTableAttr$object;

typedef struct _jc_jas_LocalVarTableAttr$fields_struct	_jc_jas_LocalVarTableAttr$fields_struct;
typedef const struct _jc_jas_LocalVarTableAttr$vmethods	_jc_jas_LocalVarTableAttr$vmethods;
typedef const struct _jc_jas_LocalVarTableAttr$vtable	_jc_jas_LocalVarTableAttr$vtable;
typedef const struct _jc_jas_LocalVarTableAttr$vtype	_jc_jas_LocalVarTableAttr$vtype;

// Class fields structure
struct _jc_jas_LocalVarTableAttr$fields_struct {
	struct _jc_jas_CP$object	*attr;
};
extern _jc_jas_LocalVarTableAttr$fields_struct _jc_jas_LocalVarTableAttr$class_fields;

// Constructors
extern void _jc_jas_LocalVarTableAttr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_LocalVarTableAttr$method$addEntry$c7f050ddb6c94fc1(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *, struct _jc_jas_LocalVarEntry$object *) _JC_JCNI_ATTR;
extern void _jc_jas_LocalVarTableAttr$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern jint _jc_jas_LocalVarTableAttr$method$size$345df5220fc60ade(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *) _JC_JCNI_ATTR;
extern void _jc_jas_LocalVarTableAttr$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_LocalVarTableAttr$method_info$addEntry$c7f050ddb6c94fc1;
extern _jc_method _jc_jas_LocalVarTableAttr$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_LocalVarTableAttr$method_info$size$345df5220fc60ade;
extern _jc_method _jc_jas_LocalVarTableAttr$method_info$write$d61e8c36d8c1cacd;

// Static methods
extern void _jc_jas_LocalVarTableAttr$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jas_LocalVarTableAttr$vmethods {
	void	(*addEntry$c7f050ddb6c94fc1)(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *, struct _jc_jas_LocalVarEntry$object *) _JC_JCNI_ATTR;
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *) _JC_JCNI_ATTR;
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_LocalVarTableAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_LocalVarTableAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_LocalVarTableAttr$vmethods	jas_LocalVarTableAttr;
};

// Vtype
struct _jc_jas_LocalVarTableAttr$vtype {
	_jc_type			type;
	_jc_jas_LocalVarTableAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LocalVarTableAttr$sub_refs {
	struct _jc_java_util_Vector$object	*vars;
};

// Reference instance fields (object)
struct _jc_jas_LocalVarTableAttr$refs {
    _jc_jas_LocalVarTableAttr$sub_refs	jas_LocalVarTableAttr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LocalVarTableAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_LocalVarTableAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_LocalVarTableAttr$sub_nonrefs	jas_LocalVarTableAttr;
};

// Object instance structure
struct _jc_jas_LocalVarTableAttr$object {
	_jc_jas_LocalVarTableAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LocalVarTableAttr$vtype	*vtype;
	_jc_jas_LocalVarTableAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LocalVarTableAttr$vtype _jc_jas_LocalVarTableAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LocalVarTableAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LocalVarTableAttr$class_object;

#endif	/* _JC_jas_LocalVarTableAttr_H_ */
